==> sassc_3.3.2.orig.tar.gz: sassc-3.3.2/Readme.md <==
SassC
=======

[![Build Status](https://secure.travis-ci.org/sass/sassc.png?branch=master)](http://travis-ci.org/sass/sassc)

Written by Aaron Leung (@akhleung) and Hampton Catlin (@hcatlin)

http://github.com/sass/sassc

About SassC
-----------

SassC is a wrapper around libsass (http://github.com/sass/libsass)
used to generate a useful command-line application that can be installed
and packaged for several operating systems.

SassC currently statically links the libsass library, but might one
day using dynamic linking if libsass supports that in the future.

About Sass
----------

Sass is a CSS pre-processor language to add on exciting, new,
awesome features to CSS. Sass was the first language of its kind
and by far the most mature and up to date codebase.

Sass was originally created by the co-creator of this library,
Hampton Catlin (@hcatlin). The extension and continuing evolution
of the language has all been the result of years of work by Natalie
Weizenbaum (@nex3) and Chris Eppstein (@chriseppstein).

For more information about Sass itself, please visit http://sass-lang.com

Documentation
-------------

* [Building on Unix](docs/building/unix-instructions.md)
* [Building on Windows](docs/building/windows-instructions.md)
* [Testing on Unix](docs/testing/unix-instructions.md)
* [Testing on Windows](docs/testing/windows-instructions.md)

Contribution Agreement
----------------------

Any contribution to the project are seen as copyright assigned to Hampton Catlin. Your contribution warrants that you have the right to assign copyright on your work. This is to ensure that the project remains free and open -- similar to the Apache Foundation.

==> sassc_3.3.6.orig.tar.gz: sassc-3.3.6/Readme.md <==
SassC
=======

[![Build Status](https://secure.travis-ci.org/sass/sassc.svg?branch=master)](http://travis-ci.org/sass/sassc)

Written by Aaron Leung (@akhleung) and Hampton Catlin (@hcatlin)

http://github.com/sass/sassc

About SassC
-----------

SassC is a wrapper around libsass (http://github.com/sass/libsass)
used to generate a useful command-line application that can be installed
and packaged for several operating systems.

SassC currently statically links the libsass library, but might one
day using dynamic linking if libsass supports that in the future.

About Sass
----------

Sass is a CSS pre-processor language to add on exciting, new,
awesome features to CSS. Sass was the first language of its kind
and by far the most mature and up to date codebase.

Sass was originally created by the co-creator of this library,
Hampton Catlin (@hcatlin). The extension and continuing evolution
of the language has all been the result of years of work by Natalie
Weizenbaum (@nex3) and Chris Eppstein (@chriseppstein).

For more information about Sass itself, please visit http://sass-lang.com

Documentation
-------------

* [Building on Unix](docs/building/unix-instructions.md)
* [Building on Windows](docs/building/windows-instructions.md)
* [Testing on Unix](docs/testing/unix-instructions.md)
* [Testing on Windows](docs/testing/windows-instructions.md)

Contribution Agreement
----------------------

Any contribution to the project are seen as copyright assigned to Hampton Catlin. Your contribution warrants that you have the right to assign copyright on your work. This is to ensure that the project remains free and open -- similar to the Apache Foundation.
